@@ -104,6 +104,12 @@ def _is_redirect(response):
         )
 
 
+def _ensure_str(s):
+    if six.PY2:
+        s = s.encode("utf-8") if isinstance(s, six.text_type) else s
+    return s
+
+
 def _cookies_from_headers(headers):
     try:
         import http.cookies as cookies
@@ -115,8 +121,10 @@ def _cookies_from_headers(headers):
     except ImportError:
         from cookies import Cookies
 
-        resp_cookies = Cookies.from_request(headers["set-cookie"])
-        cookies_dict = {v.name: v.value for _, v in resp_cookies.items()}
+        resp_cookies = Cookies.from_request(_ensure_str(headers["set-cookie"]))
+        cookies_dict = {
+            v.name: quote(_ensure_str(v.value)) for _, v in resp_cookies.items()
+        }
     return cookiejar_from_dict(cookies_dict)
 
 
@@ -390,6 +398,9 @@ class CallbackResponse(BaseResponse):
             raise result
 
         status, r_headers, body = result
+        if isinstance(body, Exception):
+            raise body
+
         body = _handle_body(body)
         headers.update(r_headers)
 
@@ -586,8 +597,9 @@ class RequestsMock(object):
                 logger.info("request.allowed-passthru", extra={"url": request.url})
                 return _real_send(adapter, request, **kwargs)
 
-            error_msg = "Connection refused: {0} {1}".format(
-                request.method, request.url
+            error_msg = (
+                "Connection refused by Responses: {0} {1} doesn't "
+                "match Responses Mock".format(request.method, request.url)
             )
             response = ConnectionError(error_msg)
             response.request = request
@@ -643,7 +655,52 @@ class RequestsMock(object):
 
 # expose default mock namespace
 mock = _default_mock = RequestsMock(assert_all_requests_are_fired=False)
-__all__ = ["CallbackResponse", "Response", "RequestsMock"]
-for __attr in (a for a in dir(_default_mock) if not a.startswith("_")):
-    __all__.append(__attr)
-    globals()[__attr] = getattr(_default_mock, __attr)
+__all__ = [
+    "CallbackResponse",
+    "Response",
+    "RequestsMock",
+    # Exposed by the RequestsMock class:
+    "activate",
+    "add",
+    "add_callback",
+    "add_passthru",
+    "assert_all_requests_are_fired",
+    "calls",
+    "DELETE",
+    "GET",
+    "HEAD",
+    "OPTIONS",
+    "passthru_prefixes",
+    "PATCH",
+    "POST",
+    "PUT",
+    "remove",
+    "replace",
+    "reset",
+    "response_callback",
+    "start",
+    "stop",
+    "target",
+]
+
+activate = _default_mock.activate
+add = _default_mock.add
+add_callback = _default_mock.add_callback
+add_passthru = _default_mock.add_passthru
+assert_all_requests_are_fired = _default_mock.assert_all_requests_are_fired
+calls = _default_mock.calls
+DELETE = _default_mock.DELETE
+GET = _default_mock.GET
+HEAD = _default_mock.HEAD
+OPTIONS = _default_mock.OPTIONS
+passthru_prefixes = _default_mock.passthru_prefixes
+PATCH = _default_mock.PATCH
+POST = _default_mock.POST
+PUT = _default_mock.PUT
+remove = _default_mock.remove
+replace = _default_mock.replace
+reset = _default_mock.reset
+response_callback = _default_mock.response_callback
+start = _default_mock.start
+stop = _default_mock.stop
+target = _default_mock.target
